package org.infinispan.server.hotrod;
/**
 * This class represents the work to be done by a decoder of a particular Hot Rod protocol version.
 * <p>
 * @author Galder Zamarre&#x00f1;o
 * @since 4.1
 */
public abstract class AbstractVersionedDecoder {
  public   AbstractVersionedDecoder () { throw new RuntimeException(); }
  public  int SecondsIn30days () { throw new RuntimeException(); }
  /**
   * Having read the message's Id, read the rest of Hot Rod header from the given buffer and return it.
   */
  public abstract  boolean readHeader (io.netty.buffer.ByteBuf buffer, byte version, long messageId, org.infinispan.server.hotrod.HotRodHeader header, boolean requireAuth) ;
  /**
   * Read the key to operate on from the message.
   */
  public abstract  scala.Tuple2<byte[], java.lang.Object> readKey (org.infinispan.server.hotrod.HotRodHeader header, io.netty.buffer.ByteBuf buffer) ;
  /**
   * Read the parameters of the operation, if present.
   */
  public abstract  scala.Tuple2<org.infinispan.server.hotrod.RequestParameters, java.lang.Object> readParameters (org.infinispan.server.hotrod.HotRodHeader header, io.netty.buffer.ByteBuf buffer) ;
  /**
   * Create a successful response.
   */
  public abstract  org.infinispan.server.hotrod.Response createSuccessResponse (org.infinispan.server.hotrod.HotRodHeader header, byte[] prev) ;
  /**
   * Create a response indicating the the operation could not be executed.
   */
  public abstract  org.infinispan.server.hotrod.Response createNotExecutedResponse (org.infinispan.server.hotrod.HotRodHeader header, byte[] prev) ;
  /**
   * Create a response indicating that the key, which the message tried to operate on, did not exist.
   */
  public abstract  org.infinispan.server.hotrod.Response createNotExistResponse (org.infinispan.server.hotrod.HotRodHeader header) ;
  /**
   * Create a response for get a request.
   */
  public abstract  org.infinispan.server.hotrod.Response createGetResponse (org.infinispan.server.hotrod.HotRodHeader header, org.infinispan.container.entries.CacheEntry entry) ;
  /**
   * Handle a protocol specific header reading.
   */
  public abstract  java.lang.Object customReadHeader (org.infinispan.server.hotrod.HotRodHeader header, io.netty.buffer.ByteBuf buffer, org.infinispan.AdvancedCache<byte[], byte[]> cache, org.infinispan.server.hotrod.HotRodServer server, io.netty.channel.ChannelHandlerContext ctx) ;
  /**
   * Handle a protocol specific key reading.
   */
  public abstract  java.lang.Object customReadKey (org.infinispan.server.hotrod.HotRodDecoder decoder, org.infinispan.server.hotrod.HotRodHeader header, io.netty.buffer.ByteBuf buffer, org.infinispan.AdvancedCache<byte[], byte[]> cache, org.infinispan.server.hotrod.HotRodServer server, io.netty.channel.Channel ch) ;
  /**
   * Handle a protocol specific value reading.
   */
  public abstract  java.lang.Object customReadValue (org.infinispan.server.hotrod.HotRodDecoder decoder, org.infinispan.server.hotrod.HotRodHeader header, org.infinispan.server.hotrod.CacheDecodeContext hrCtx, io.netty.buffer.ByteBuf buffer, org.infinispan.AdvancedCache<byte[], byte[]> cache) ;
  /**
   * Create a response for the stats command.
   */
  public abstract  org.infinispan.server.hotrod.StatsResponse createStatsResponse (org.infinispan.server.hotrod.CacheDecodeContext hrCtx, org.infinispan.server.core.transport.NettyTransport t) ;
  /**
   * Create an error response based on the Throwable instance received.
   */
  public abstract  org.infinispan.server.hotrod.ErrorResponse createErrorResponse (org.infinispan.server.hotrod.HotRodHeader header, java.lang.Throwable t) ;
  /**
   * Get an optimized cache instance depending on the operation parameters.
   */
  public abstract  org.infinispan.AdvancedCache<byte[], byte[]> getOptimizedCache (org.infinispan.server.hotrod.HotRodHeader h, org.infinispan.AdvancedCache<byte[], byte[]> c, org.infinispan.configuration.cache.Configuration cacheCfg) ;
  /**
   * Transforms lifespan pass as seconds into milliseconds
   * following this rule (inspired by Memcached):
   * <p>
   * If lifespan is bigger than number of seconds in 30 days,
   * then it is considered unix time. After converting it to
   * milliseconds, we subtract the current time in and the
   * result is returned.
   * <p>
   * Otherwise it's just considered number of seconds from
   * now and it's returned in milliseconds unit.
   */
  public  long toMillis (org.infinispan.server.hotrod.ExpirationParam param, org.infinispan.server.hotrod.HotRodHeader h) { throw new RuntimeException(); }
}
